==> flutter_app_packager-0.2.5.tar.gz: lib/src/makers/msix/app_package_maker_msix.dart <==
import 'dart:io';

import 'package:app_package_maker/app_package_maker.dart';
import 'package:path/path.dart' as p;
import 'package:shell_executor/shell_executor.dart';

import 'make_msix_config.dart';

class AppPackageMakerMsix extends AppPackageMaker {
  String get name => 'msix';
  String get platform => 'windows';
  String get packageFormat => 'msix';

  bool get isSupportedOnCurrentPlatform => Platform.isWindows;

  @override
  Future<MakeConfig> loadMakeConfig(
    Directory outputDirectory,
    Map<String, dynamic>? makeArguments,
  ) async {
    MakeConfig baseMakeConfig = await super.loadMakeConfig(
      outputDirectory,
      makeArguments,
    );
    final map = loadMakeConfigYaml('windows/packaging/msix/make_config.yaml');
    return MakeMsixConfig.fromJson(map).copyWith(baseMakeConfig);
  }

  @override
  Future<MakeResult> make(
    Directory appDirectory, {
    required Directory outputDirectory,
    Map<String, dynamic>? makeArguments,
  }) async {
    MakeMsixConfig makeConfig = (await loadMakeConfig(
      outputDirectory,
      makeArguments,
    ) as MakeMsixConfig);

    makeConfig.output_path = makeConfig.outputFile.parent.path;
    makeConfig.output_name =
        p.basenameWithoutExtension(makeConfig.outputFile.path);
    makeConfig.build_windows = 'false';

    Map<String, dynamic> makeConfigJson = makeConfig.toJson();
    List<String> arguments = [];
    for (String key in makeConfigJson.keys) {
      dynamic value = makeConfigJson[key];
      String newKey = key.replaceAll('_', '-');
      if (newKey == 'msix-version') newKey = 'version';

      if (value is Map) {
        for (String subKey in value.keys) {
          arguments.addAll(['--$newKey', '$subKey=${value[subKey]}']);
        }
      } else {
        arguments.addAll(['--$newKey', value]);
      }
    }
    await $(
      'flutter',
      ['pub', 'run', 'msix:create']..addAll(arguments),
    );
    return MakeResult(makeConfig);
  }
}

==> flutter_app_packager-0.3.0.tar.gz: lib/src/makers/msix/app_package_maker_msix.dart <==
import 'dart:io';

import 'package:app_package_maker/app_package_maker.dart';
import 'package:flutter_app_packager/src/makers/msix/make_msix_config.dart';
import 'package:path/path.dart' as p;
import 'package:shell_executor/shell_executor.dart';

class AppPackageMakerMsix extends AppPackageMaker {
  @override
  String get name => 'msix';
  @override
  String get platform => 'windows';
  @override
  bool get isSupportedOnCurrentPlatform => Platform.isWindows;
  @override
  String get packageFormat => 'msix';

  @override
  MakeConfigLoader get configLoader {
    return MakeMsixConfigLoader()
      ..platform = platform
      ..packageFormat = packageFormat;
  }

  @override
  Future<MakeResult> make(MakeConfig config) {
    return _make(
      config.buildOutputDirectory,
      outputDirectory: config.outputDirectory,
      makeConfig: config as MakeMsixConfig,
    );
  }

  Future<MakeResult> _make(
    Directory appDirectory, {
    required Directory outputDirectory,
    required MakeMsixConfig makeConfig,
  }) async {
    makeConfig.output_path = makeConfig.outputFile.parent.path;
    makeConfig.output_name =
        p.basenameWithoutExtension(makeConfig.outputFile.path);
    makeConfig.build_windows = 'false';

    Map<String, dynamic> makeConfigJson = makeConfig.toJson();
    List<String> arguments = [];
    for (String key in makeConfigJson.keys) {
      dynamic value = makeConfigJson[key];
      String newKey = key.replaceAll('_', '-');
      if (newKey == 'msix-version') newKey = 'version';

      if (value is Map) {
        for (String subKey in value.keys) {
          arguments.addAll(['--$newKey', '$subKey=${value[subKey]}']);
        }
      } else {
        arguments.addAll(['--$newKey', value]);
      }
    }
    await $(
      'flutter',
      ['pub', 'run', 'msix:create', ...arguments],
    );
    return MakeResult(makeConfig);
  }
}
